@@ -38,6 +38,7 @@ using namespace dde::network;
 #define CONNECTED  2
 
 Connectivity NetworkModel::m_Connectivity(Connectivity::Full);
+QStringList NetworkModel::m_deviceInterface;
 
 NetworkDevice::DeviceType parseDeviceType(const QString &type)
 {
@@ -226,6 +227,8 @@ void NetworkModel::onDevicesChanged(const QString &devices)
 
     bool changed = false;
 
+    m_deviceInterface.clear();
+
     for (auto it(data.constBegin()); it != data.constEnd(); ++it) {
         const auto type = parseDeviceType(it.key());
         const auto list = it.value().toArray();
@@ -237,6 +240,16 @@ void NetworkModel::onDevicesChanged(const QString &devices)
         {
             const auto info = l.toObject();
             const QString path = info.value("Path").toString();
+            bool managed = info.value("Managed").toBool();
+            QString interface = info.value("Interface").toString();
+
+            if (!m_deviceInterface.contains(interface))
+                m_deviceInterface << interface;
+
+            if (!managed) {
+                qDebug() << "device: " << path << "ignored due to unmanged";
+                continue;
+            }
 
             // 根据标志位InterfaceFlags判断网络连接是否有效
             if (type != NetworkDevice::Wireless) {
@@ -316,6 +329,9 @@ void NetworkModel::onConnectionListChanged(const QString &conns)
     QMap<QString, QList<QJsonObject>> commonConnections;
     QMap<QString, QMap<QString, QList<QJsonObject>>> deviceConnections;
 
+    QMap<QString, QList<QJsonObject>> wiredCommonConnections;
+    QMap<QString, QMap<QString, QList<QJsonObject>>> wiredDeviceConnections;
+
     // 解析所有的 connection
     const QJsonObject connsObject = QJsonDocument::fromJson(conns.toUtf8()).object();
     for (auto it(connsObject.constBegin()); it != connsObject.constEnd(); ++it) {
@@ -337,6 +353,13 @@ void NetworkModel::onConnectionListChanged(const QString &conns)
             } else {
                 deviceConnections[hwAddr][connType].append(connection);
             }
+
+            const auto &interface = connection.value("IfcName").toString();
+            if (interface.isEmpty()) {
+                wiredCommonConnections[connType].append(connection);
+            } else {
+                wiredDeviceConnections[interface][connType].append(connection);
+            }
         }
     }
 
@@ -344,12 +367,14 @@ void NetworkModel::onConnectionListChanged(const QString &conns)
     for (NetworkDevice *dev : m_devices) {
         const QString &hwAddr = dev->realHwAdr();
         const QMap<QString, QList<QJsonObject>> &connsByType = deviceConnections.value(hwAddr);
+        const QString &inter = dev->interfaceName();
+        const QMap<QString, QList<QJsonObject>> &connsByInter = wiredDeviceConnections.value(inter);
         QList<QJsonObject> destConns;
 
         switch (dev->type()) {
         case NetworkDevice::Wired: {
-            destConns += commonConnections.value("wired");
-            destConns += connsByType.value("wired");
+            destConns += wiredCommonConnections.value("wired");
+            destConns += connsByInter.value("wired");
             WiredDevice *wdDevice = static_cast<WiredDevice *>(dev);
             wdDevice->setConnections(destConns);
             break;
@@ -597,12 +622,12 @@ void NetworkModel::onConnectivityChanged(int connectivity)
 
     // if the new connectivity state from NetworkManager is not Full,
     // check it again use our urls
-    if (m_Connectivity != Full) {
-        if (!m_connectivityCheckThread->isRunning()) {
-            m_connectivityCheckThread->start();
-        }
-        Q_EMIT needCheckConnectivitySecondary();
-    }
+    // if (m_Connectivity != Full) {
+    //     if (!m_connectivityCheckThread->isRunning()) {
+    //         m_connectivityCheckThread->start();
+    //     }
+    //     Q_EMIT needCheckConnectivitySecondary();
+    // }
 
     Q_EMIT connectivityChanged(m_Connectivity);
 }
